"""Auto-generated file, do not edit by hand. 505 metadata"""
from ..phonemetadata import NumberFormat

PHONE_ALT_FORMAT_505 = [NumberFormat(pattern='(\\d)(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['2'])]
